# biocircuits

Utilities Caltech BE 150: Design Principles of Genetic Circuits


## Installation / Usage

To install use pip:

    pip install biocircuits


Or clone the repo:

    git clone https://github.com/justinbois/biocircuits.git
    python setup.py install
